@@ -20,6 +20,7 @@
 
 
 import os
+import yaml
 import uuid
 import json
 import unittest
@@ -175,6 +176,16 @@ class TestMultinode(unittest.TestCase):  # pylint: disable=too-many-public-metho
             self.assertIs(True, protocol.valid)
         self.assertIsNone(self.coord.dataReceived({}))
 
+    @unittest.skipIf(not os.path.exists('/dev/loop0'), "loopback support not found")
+    def test_multinode_description(self):
+        self.assertIsNotNone(self.client_job)
+        self.client_job.validate()
+        # check that the description can be re-loaded as valid YAML
+        for action in self.client_job.pipeline.actions:
+            data = action.explode()
+            data_str = yaml.dump(data)
+            yaml.load(data_str)
+
     def test_multinode_timeout(self):
         """
         Test the protocol timeout is assigned to the action
@@ -567,8 +578,16 @@ class TestProtocol(unittest.TestCase):  # pylint: disable=too-many-public-method
         def close(self):
             pass
 
-        def recv(self, _):
-            self.coord._waitResponse()
+        def recv(self, msg):
+            """
+            Allow the fake to send a properly formatted response.
+            """
+            if self.header:
+                self.header = False
+                return '1000'  # int('1000', 16) == 4096
+            else:
+                self.header = True
+                return json.dumps({'response': 'ack'})
 
     class FakeProtocol(MultinodeProtocol):
 
@@ -582,6 +601,12 @@ class TestProtocol(unittest.TestCase):  # pylint: disable=too-many-public-method
         def _connect(self, delay):
             return True
 
+        def finalise_protocol(self):
+            """
+            Allow the fake coordinator to finalise the protocol
+            """
+            pass
+
         def __call__(self, *args, **kwargs):
             super(TestProtocol.FakeProtocol, self).__call__(*args, **kwargs)
 
@@ -629,7 +654,19 @@ class TestProtocol(unittest.TestCase):  # pylint: disable=too-many-public-method
         with self.assertRaises(TestError):
             self.protocol(msg)
 
-    def test_lava_send_fail(self):
+    def test_lava_send_too_long(self):
+        msg = {
+            'request': 'lava_send',
+            'port': 3,
+            'blocksize': 8,
+            'messageID': 'a' * (int('0xFFFE', 16) + 10)
+        }
+        msg.update(self.protocol.base_message)
+        self.coord.expectResponse("ack")
+        with self.assertRaises(JobError):
+            self.protocol(msg)
+
+    def test_lava_send(self):
         msg = {
             'request': 'lava_send',
             'port': 3,
@@ -637,8 +674,23 @@ class TestProtocol(unittest.TestCase):  # pylint: disable=too-many-public-method
             'messageID': 'test-id'
         }
         msg.update(self.protocol.base_message)
-        with self.assertRaises(TestError):
-            self.protocol(msg)
+        self.coord.expectResponse("ack")
+        self.protocol(msg)
+
+    def test_lava_send_message(self):
+        msg = {
+            'request': 'lava_send',
+            'port': 3,
+            'blocksize': 8,
+            'messageID': 'test-id',
+            'message': {
+                'one': 1,
+                'two': 2
+            }
+        }
+        msg.update(self.protocol.base_message)
+        self.coord.expectResponse("ack")
+        self.protocol(msg)
 
 
 class TestDelayedStart(unittest.TestCase):  # pylint: disable=too-many-public-methods
